NthBitLogic

Trait NthBitLogic 

pub trait NthBitLogic {
    // Required method
    fn nth_bit(self, n: Int) -> bool;
}
Trait for the nth bit of a bitvector in logic code.

Required Methods

fn nth_bit(self, n: Int) -> bool

The nth bit of a bitvector. In bitwise_proof mode, this is translated to nth in Why3. Otherwise this is an abstract function.

logic

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl NthBitLogic for i8

Source

fn nth_bit(self, n: Int) -> bool

logic

Source

impl NthBitLogic for i16

Source

fn nth_bit(self, n: Int) -> bool

logic

Source

impl NthBitLogic for i32

Source

fn nth_bit(self, n: Int) -> bool

logic

Source

impl NthBitLogic for i64

Source

fn nth_bit(self, n: Int) -> bool

logic

Source

impl NthBitLogic for i128

Source

fn nth_bit(self, n: Int) -> bool

logic

Source

impl NthBitLogic for isize

Source

fn nth_bit(self, n: Int) -> bool

logic

Source

impl NthBitLogic for u8

Source

fn nth_bit(self, n: Int) -> bool

logic

Source

impl NthBitLogic for u16

Source

fn nth_bit(self, n: Int) -> bool

logic

Source

impl NthBitLogic for u32

Source

fn nth_bit(self, n: Int) -> bool

logic

Source

impl NthBitLogic for u64

Source

fn nth_bit(self, n: Int) -> bool

logic

Source

impl NthBitLogic for u128

Source

fn nth_bit(self, n: Int) -> bool

logic

Source

impl NthBitLogic for usize

Source

fn nth_bit(self, n: Int) -> bool

logic

Implementors